Extensions

Struct Extensions 

pub struct Extensions<V>(/* private fields */);

Implementations

Source

impl<V> Extensions<V>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn contains(&self, key: &impl Borrow<str>) -> bool

pub fn get_raw(&self, key: &impl Borrow<str>) -> Option<&V>

pub fn insert(&mut self, key: Nsid, value: V) -> Option<V>

Source

impl<V: Value + Clone> Extensions<V>

pub fn get<'de, T: Deserialize<'de>>( &'de self, key: &impl Borrow<str>, ) -> Option<Result<T, V::Error>>

Gets an extension’s value by key, or returns None if the key doesn’t exist.

pub fn require<'de, T: Deserialize<'de>>( &'de self, key: &impl Borrow<str>, ) -> Result<T, V::Error>

Get’s an extension’s value by key, returning an error if the key doesn’t exist or doesn’t deserialize into the provided type.